@@ -30,10 +30,10 @@ class CleanDataset(object):
         ----------
         check_arm_syntax : boolean
             ARM ueses a standard of starting all quality control variables
-            with "qc\_". This is a more robust method of getting the quality
-            control variables before the standard_name attribute is added.
-            If this is true will first check using attributes and will then
-            check if variable starts with "qc\_".
+            with "qc" joined with an underscore. This is a more robust method
+            of getting the quality control variables before the standard_name
+            attribute is added. If this is true will first check using
+            attributes and will then check if variable starts with "qc".
 
         Returns
         -------
@@ -49,7 +49,7 @@ class CleanDataset(object):
                     ("This field contains bit packed integer values, where each "
                      "bit represents a QC test on the data. Non-zero bits indicate "
                      "the QC condition given in the description for those bits; "
-                     "a value of 0 \(no bits set\) indicates the data has not "
+                     "a value of 0.+ indicates the data has not "
                      "failed any QC tests."),
                     (r"This field contains bit packed values which should be "
                      r"interpreted as listed..+")
@@ -78,6 +78,7 @@ class CleanDataset(object):
 
     def cleanup(self, cleanup_arm_qc=True, clean_arm_state_vars=None,
                 handle_missing_value=True, link_qc_variables=True,
+                normalize_assessment=False,
                 **kwargs):
         """
         Wrapper method to automatically call all the standard methods
@@ -101,6 +102,10 @@ class CleanDataset(object):
         link_qc_variables : bool
             Option to link QC variablers through ancillary_variables if not
             already set.
+        normalize_assessment : bool
+            Option to clean up assessments to use the same terminology. Set to
+            False for default because should only be an issue after adding DQRs
+            and the function to add DQRs calls this method.
         **kwargs : keywords
             Keyword arguments passed through to clean.clean_arm_qc
             method.
@@ -125,6 +130,10 @@ class CleanDataset(object):
         if link_qc_variables:
             self._obj.clean.link_variables()
 
+        # Update the terminology used with flag_assessments to be consistent
+        if normalize_assessment:
+            self._obj.clean.normalize_assessment()
+
     def handle_missing_values(self, default_missing_value=np.int32(-9999)):
         """
         Correctly handle missing_value and _FillValue in object.
@@ -254,9 +263,10 @@ class CleanDataset(object):
                 var = self.matched_qc_variables
                 if len(var) > 0:
                     try:
-                        flag_method = self._obj[var[0]].attrs['flag_method']
-                        string = flag_method
+                        if self._obj[variable].attrs['flag_method'] == 'integer':
+                            string = 'flag'
                         found_string = True
+                        del self._obj[variable].attrs['flag_method']
                     except KeyError:
                         pass
 
@@ -594,7 +604,7 @@ class CleanDataset(object):
             # Remove replaced attributes
             if qc_attributes is not None:
                 arm_attributes = qc_attributes['arm_attributes']
-                arm_attributes.extend(['description', 'flag_method'])
+                arm_attributes.extend(['description'])  # , 'flag_method'])
                 for attr in arm_attributes:
                     try:
                         del self._obj[qc_var].attrs[attr]
@@ -614,3 +624,54 @@ class CleanDataset(object):
                     del self._obj.attrs[attr]
                 except KeyError:
                     pass
+
+    def normalize_assessment(self, variables=None, exclude_variables=None,
+                             qc_lookup={"Incorrect": "Bad", "Suspect": "Indeterminate"}):
+
+        """
+        Method to clean up assessment terms used to be consistent between
+        embedded QC and DQRs.
+
+        Parameters
+        ----------
+        variables : str or list of str
+            Optional data variable names to check and normalize. If set to
+            None will check all variables.
+        exclude_variables : str or list of str
+            Optional data variable names to exclude from processing.
+        qc_lookup : dict
+            Optional dictionary used to convert between terms.
+
+        """
+
+        # Get list of variables if not provided
+        if variables is None:
+            variables = list(self._obj.data_vars)
+
+        # Ensure variables is a list
+        if not isinstance(variables, (list, tuple)):
+            variables = [variables]
+
+        # If exclude variables provided remove from variables list
+        if exclude_variables is not None:
+            if not isinstance(exclude_variables, (list, tuple)):
+                exclude_variables = [exclude_variables]
+
+            variables = list(set(variables) - set(exclude_variables))
+
+        # Loop over variables checking if a QC variable exits and use the
+        # lookup dictionary to convert the assessment terms.
+        for var_name in variables:
+            qc_var_name = self._obj.qcfilter.check_for_ancillary_qc(
+                var_name, add_if_missing=False, cleanup=False)
+            if qc_var_name is not None:
+                try:
+                    flag_assessments = self._obj[qc_var_name].attrs['flag_assessments']
+                except KeyError:
+                    continue
+
+                for ii, assess in enumerate(flag_assessments):
+                    try:
+                        flag_assessments[ii] = qc_lookup[assess]
+                    except KeyError:
+                        continue
