@@ -28,7 +28,7 @@ class QCFilter(qctests.QCTests, comparison_tests.QCTests, object):
         self._obj = xarray_obj
 
     def check_for_ancillary_qc(self, var_name, add_if_missing=True,
-                               cleanup=True):
+                               cleanup=True, flag_type=False):
         """
         Method to check if a quality control variable exist in the dataset
         and return the quality control varible name.
@@ -48,6 +48,9 @@ class QCFilter(qctests.QCTests, comparison_tests.QCTests, object):
             Option to run qc.clean.cleanup() method on the object
             to ensure the object was updated from ARM QC to the
             correct standardized QC.
+        flag_type : boolean
+            Indicating the QC variable uses flag_values instead of
+            flag_masks.
 
         Returns
         -------
@@ -70,7 +73,8 @@ class QCFilter(qctests.QCTests, comparison_tests.QCTests, object):
                         qc_var_name = var
 
             if add_if_missing and qc_var_name is None:
-                qc_var_name = self._obj.qcfilter.create_qc_variable(var_name)
+                qc_var_name = self._obj.qcfilter.create_qc_variable(
+                    var_name, flag_type=flag_type)
 
         except KeyError:
             # Since no ancillary_variables exist look for ARM style of QC
@@ -82,7 +86,7 @@ class QCFilter(qctests.QCTests, comparison_tests.QCTests, object):
                     qc_var_name = 'qc_' + var_name
                 except KeyError:
                     qc_var_name = self._obj.qcfilter.create_qc_variable(
-                        var_name)
+                        var_name, flag_type=flag_type)
 
         # Make sure data varaible has a variable attribute linking
         # data variable to QC variable.
@@ -176,6 +180,8 @@ class QCFilter(qctests.QCTests, comparison_tests.QCTests, object):
         self._obj[qc_var_name].attrs['flag_assessments'] = []
         self._obj[qc_var_name].attrs['standard_name'] = 'quality_flag'
 
+        self.update_ancillary_variable(var_name, qc_var_name=qc_var_name)
+
         return qc_var_name
 
     def update_ancillary_variable(self, var_name, qc_var_name=None):
@@ -195,7 +201,7 @@ class QCFilter(qctests.QCTests, comparison_tests.QCTests, object):
         """
         if qc_var_name is None:
             qc_var_name = self._obj.qcfilter.check_for_ancillary_qc(
-                self, var_name, add_if_missing=False)
+                var_name, add_if_missing=False)
 
         if qc_var_name is None:
             return
@@ -270,7 +276,8 @@ class QCFilter(qctests.QCTests, comparison_tests.QCTests, object):
         # Ensure assessment is lowercase and capitalized to be consistent
         test_assessment = test_assessment.lower().capitalize()
 
-        qc_var_name = self._obj.qcfilter.check_for_ancillary_qc(var_name)
+        qc_var_name = self._obj.qcfilter.check_for_ancillary_qc(
+            var_name, flag_type=flag_value)
 
         if test_number is None:
             test_number = self._obj.qcfilter.available_bit(
@@ -279,14 +286,26 @@ class QCFilter(qctests.QCTests, comparison_tests.QCTests, object):
         self._obj.qcfilter.set_test(var_name, index, test_number, flag_value)
 
         if flag_value:
-            self._obj[qc_var_name].attrs['flag_values'].append(test_number)
+            try:
+                self._obj[qc_var_name].attrs['flag_values'].append(test_number)
+            except KeyError:
+                self._obj[qc_var_name].attrs['flag_values'] = [test_number]
         else:
-            self._obj[qc_var_name].attrs['flag_masks'].append(
-                set_bit(0, test_number))
+            try:
+                self._obj[qc_var_name].attrs['flag_masks'].append(
+                    set_bit(0, test_number))
+            except KeyError:
+                self._obj[qc_var_name].attrs['flag_masks'] = [set_bit(0, test_number)]
 
-        self._obj[qc_var_name].attrs['flag_meanings'].append(test_meaning)
+        try:
+            self._obj[qc_var_name].attrs['flag_meanings'].append(test_meaning)
+        except KeyError:
+            self._obj[qc_var_name].attrs['flag_meanings'] = [test_meaning]
 
-        self._obj[qc_var_name].attrs['flag_assessments'].append(test_assessment)
+        try:
+            self._obj[qc_var_name].attrs['flag_assessments'].append(test_assessment)
+        except KeyError:
+            self._obj[qc_var_name].attrs['flag_assessments'] = [test_assessment]
 
         test_dict['test_number'] = test_number
         test_dict['test_meaning'] = test_meaning
@@ -379,7 +398,7 @@ class QCFilter(qctests.QCTests, comparison_tests.QCTests, object):
             Index to set test in quality control array. If want to
             unset all values will need to pass in index of all values.
         test_number : int
-            Test number to remove.
+            Test number to set.
         flag_value : boolean
             Switch to use flag_values integer quality control.
 
@@ -631,7 +650,7 @@ class QCFilter(qctests.QCTests, comparison_tests.QCTests, object):
                 result = ds_object.qcfilter.add_test(
                     var_name, index=[0, 1, 2], test_meaning='Birds!')
                     data = ds_object.qcfilter.get_masked_data(var_name,
-                    rm_assessments=['Bad', 'Suspect'])
+                    rm_assessments=['Bad', 'Indeterminate'])
                 print(data)
                 masked_array(data=[--, --, --, ..., 7.670499801635742,
                     7.689199924468994, 7.689199924468994],
@@ -639,6 +658,7 @@ class QCFilter(qctests.QCTests, comparison_tests.QCTests, object):
                     fill_value=1e+20, dtype=float32)
 
         """
+
         qc_var_name = self._obj.qcfilter.check_for_ancillary_qc(
             var_name, add_if_missing=False)
 
@@ -714,6 +734,93 @@ class QCFilter(qctests.QCTests, comparison_tests.QCTests, object):
 
         return variable
 
+    def datafilter(self, variables=None, rm_assessments=None, rm_tests=None,
+                   np_ma=True, verbose=False, del_qc_var=True):
+        """
+        Method to apply quality control variables to data variables by
+        changing the data values in the dataset using quality control variables.
+        The data variable is changed to to a numpy masked array with failing data
+        masked or, if requested, to numpy array with failing data set to NaN.
+        This can be used to update the data variable in the xarray dataset for use with
+        xarray methods to perform analysis on the data since those methods don't
+        read the quality control variables.
+
+        Parameters
+        ----------
+        variables : None or str or list of str
+            Data variable names to process
+        rm_assessments : str or list of str
+            Assessment names listed under quality control varible flag_assessments
+            to exclude from returned data. Examples include
+            ['Bad', 'Incorrect', 'Indeterminate', 'Suspect']
+        rm_tests : int or list of int
+            Test numbers listed under quality control variable to exclude from
+            returned data. This is the test
+            number (or bit position number) not the mask number.
+        np_ma : boolean
+            Shoudl the data in the xarray DataArray be set to numpy masked
+            arrays. This shoudl work with most xarray methods. If the xarray
+            processing method does not work with numpy masked array set to
+            False to use NaN.
+        verbose : boolean
+            Print processing information.
+        del_qc_var : boolean
+            Opttion to delete quality control variable after processing. Since
+            the data values can not be determined after they are set to NaN
+            and xarray method processing would also process the quality control
+            variables, the default is to remove the quality control data variables.
+            If numpy masked arrays are used the data are not lost but would need
+            to be extracted and set to DataArray to return the dataset back to orginal state.
+
+
+        Examples
+        --------
+            .. code-block:: python
+
+                from act.io.armfiles import read_netcdf
+                from act.tests import EXAMPLE_MET1
+
+                ds = read_netcdf(EXAMPLE_MET1)
+                ds.clean.cleanup()
+
+                var_name = 'atmos_pressure'
+
+                ds_1 = ds.mean()
+
+                ds.qcfilter.add_less_test(var_name, 99, test_assessment='Bad')
+                ds.qcfilter.datafilter(rm_assessments='Bad')
+                ds_2 = ds.mean()
+                print(f'All data: {ds_1[var_name].values}, Bad Removed: {ds_2[var_name].values}')
+                All data: 98.86097717285156, Bad Removed: 99.15148162841797
+
+        """
+
+        if variables is not None and isinstance(variables, str):
+            variables = [variables]
+
+        if variables is None:
+            variables = list(self._obj.data_vars)
+
+        for var_name in variables:
+            qc_var_name = self.check_for_ancillary_qc(var_name,
+                                                      add_if_missing=False,
+                                                      cleanup=False)
+            if qc_var_name is None:
+                if verbose:
+                    print(f'No quality control variable for {var_name} found '
+                          f'in call to .qcfilter.datafilter()')
+                continue
+
+            data = self.get_masked_data(var_name, rm_assessments=rm_assessments,
+                                        rm_tests=rm_tests, ma_fill_value=np_ma)
+
+            self._obj[var_name].values = data
+
+            if del_qc_var:
+                del self._obj[qc_var_name]
+                if verbose:
+                    print(f'Deleting {qc_var_name} from dataset')
+
 
 def set_bit(array, bit_number):
     """
