@@ -11,6 +11,10 @@ This module contains various retrievals for datsets.
     :toctree: generated/
 
     aeri2irt
+    calculate_dsh_from_dsdh_sdn
+    calculate_irradiance_stats
+    calculate_net_radiation
+    calculate_longwave_radiation
     calculate_precipitable_water
     calculate_stability_indicies
     compute_winds_from_ppi
@@ -26,3 +30,7 @@ from .doppler_lidar import compute_winds_from_ppi
 from .aeri import aeri2irt
 from .irt import sst_from_irt
 from .irt import sum_function_irt
+from .radiation import calculate_dsh_from_dsdh_sdn
+from .radiation import calculate_irradiance_stats
+from .radiation import calculate_net_radiation
+from .radiation import calculate_longwave_radiation
